@@ -1,4 +1,4 @@
-package Mojolicious::Plugin::BootstrapHelpers 0.0186 {
+package Mojolicious::Plugin::BootstrapHelpers 0.0187 {
 
     use strict;
     use warnings;
@@ -13,7 +13,8 @@ package Mojolicious::Plugin::BootstrapHelpers 0.0186 {
     use String::Trim;
     use Mojolicious::Plugin::BootstrapHelpers::Helpers;
 
-    use experimental 'postderef'; # requires 5.20
+    use 5.20.0;
+    use experimental 'postderef';
 
     sub register {
         my $self = shift;
@@ -100,7 +101,7 @@ Mojolicious::Plugin::BootstrapHelpers - Type less bootstrap
 
 This is an unstable work in progress. Backwards compatibility is currently not to be expected between releases.
 
-Currently supported Bootstrap version: 3.3.0.
+Currently supported Bootstrap version: 3.3.1.
 
 Currently only Perl 5.20+ is supported (thanks to postderef).
 
@@ -1034,6 +1035,23 @@ A formgroup used in a <code>.form-horizontal</code> <code>form</code>.
 =end html
 
 
+    %= formgroup 'Text test 9', text_area => ['atextarea', 'default text']
+
+    <div class="form-group">
+        <label class="control-label" for="atextarea">Text test 9</label>
+        <textarea class="form-control" id="atextarea" name="atextarea">default text</textarea>
+    </div>
+
+=begin html
+
+<p>
+Textareas can also be used in formgroups.
+
+</p>
+
+=end html
+
+
 
 
 =head2 Icons
